==> swi-prolog_5.10.4.orig.tar.gz: pl-5.10.4/packages/pldoc/doc_debug.pl <==
/*  $Id$

    Part of SWI-Prolog

    Author:        Jan Wielemaker
    E-mail:        wielemak@science.uva.nl
    WWW:           http://www.swi-prolog.org
    Copyright (C): 1985-2006, University of Amsterdam

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    As a special exception, if you link this library with other files,
    compiled with a Free Software compiler, to produce an executable, this
    library does not by itself cause the resulting executable to be covered
    by the GNU General Public License. This exception does not however
    invalidate any other reasons why the executable file might be covered by
    the GNU General Public License.
*/

:- module(pldoc_debug,
	  []).

		 /*******************************
		 *	       DEBUG		*
		 *******************************/

:- multifile
        user:portray/1.

user:portray(X) :-
	codes(X),
	length(X, Len),
	Len > 2,
	format('"~s"', [X]).

codes([]).
codes([H|T]) :-
	code(H),
	codes(T).

code(9) :- !.
code(10) :- !.
code(H) :-
	integer(H),
	between(32, 126, H).

==> swi-prolog_6.6.4.orig.tar.gz: pl-6.6.4/packages/pldoc/doc_debug.pl <==
/*  $Id$

    Part of SWI-Prolog

    Author:        Jan Wielemaker
    E-mail:        wielemak@science.uva.nl
    WWW:           http://www.swi-prolog.org
    Copyright (C): 1985-2006, University of Amsterdam

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    As a special exception, if you link this library with other files,
    compiled with a Free Software compiler, to produce an executable, this
    library does not by itself cause the resulting executable to be covered
    by the GNU General Public License. This exception does not however
    invalidate any other reasons why the executable file might be covered by
    the GNU General Public License.
*/

:- module(pldoc_debug,
	  []).

		 /*******************************
		 *	       DEBUG		*
		 *******************************/

:- multifile
        user:portray/1.

user:portray(X) :-
	codes(X),
	length(X, Len),
	Len > 2,
	format('"~s"', [X]).

codes([]).
codes([H|T]) :-
	code(H),
	codes(T).

code(9) :- !.
code(10) :- !.
code(H) :-
	integer(H),
	between(32, 126, H).
